<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Handle frontend forms.
 *
 * @class Quick_Form_Handler
 *
 * @version 1.1.3
 *
 * @category Class
 *
 * @author webkul
 */
class Quick_Form_Handler
{
    /**
     * Constructor.
     */
    public function __construct()
    {
        add_action('admin_init', array($this, 'default_quick_settings'));

        add_action('wp_enqueue_scripts', array($this, 'quick_enqueue_script'), 100);
        add_shortcode('quick_order', array($this, 'quick_order_cart'));

        add_action('wp_ajax_nopriv_get_input_search_products', 'get_input_search_products');
        add_action('wp_ajax_get_input_search_products', 'get_input_search_products');

        add_action('wp_ajax_nopriv_get_add_product_tmpl', 'get_add_product_tmpl');
        add_action('wp_ajax_get_add_product_tmpl', 'get_add_product_tmpl');

        add_action('wp_ajax_nopriv_get_input_selected_product', 'get_input_selected_product');
        add_action('wp_ajax_get_input_selected_product', 'get_input_selected_product');
        add_action('process_quick_order_to_cart', 'bulk_add_multiple_products_to_cart', 1);

        add_action('process_quick_order_to_cart_via_csv', 'bulk_add_multiple_products_via_csv_to_cart', 1);

        add_filter( 'woocommerce_screen_ids', array( $this, 'wkqs_set_screens' ) );
    }

    public function wkqs_set_screens( $screens ) {
        
        $screens[] = 'toplevel_page_quick-order';
        return $screens;
    }
    
    public function quick_enqueue_script()
    {
        wp_register_style('quick-css', QUICK_API.'/assets/css/quick.css', array(), QUICK_VERSION );
        wp_enqueue_style( 'quick-css' );
    }

    public function default_quick_settings()
    {
        // General Settings.
        register_setting( 'quick-order-settings-group', '_csv_quick_order_create_by' );
        register_setting( 'quick-order-settings-group', '_quick_blank_rows' );
        register_setting( 'quick-order-settings-group', '_quick_no_rows', array( $this, 'quick_order_validate_option' ) );
        register_setting( 'quick-order-settings-group', '_quick_no_rows_add', array( $this, 'quick_order_validate_option' ) );
        register_setting( 'quick-order-settings-group', '_search_product_by' );
        register_setting( 'quick-order-settings-group', '_create_combination_feild' );
    }

    public function quick_order_validate_option($data)
    {
        if (empty($data)) {
            add_settings_error(
                'requiredTextFieldEmpty',
                'empty',
                esc_html__( 'Fields cannot be empty', 'wk_quick' ),
                'error'
            );
        } elseif ( (int)$data <= 0) {
            add_settings_error(
                'requiredTextFieldEmpty',
                'empty',
                esc_html__( 'Number must be greater than 0.', 'wk_quick' ),
                'error'
            );
        } else {
            return sanitize_text_field($data);
        }
    }

    public function quick_order_cart()
    {
        ob_start();

        quick_get_template_part('tmpl/quick-order-tmpl');

        return ob_get_clean();
    }
}

new Quick_Form_Handler();