<?php

if ( ! defined( 'ABSPATH' ) ) {
    exit(0);
}

// include admin menu
if ( ! function_exists( 'webkul_quick_order_admin_menu' ) ) {
    function webkul_quick_order_admin_menu()
    {
        require_once QUICK_DIR.'/includes/admin/menu-items.php';
    }
}

// Basic settings for quick order module

if (!function_exists('wc_quick_screen_option')) {
    function wc_quick_screen_option()
    {
        $options = 'per_page';

        $args = array(
        'label'   => esc_html__( 'Options Per Page', 'wk_quick' ),
        'default' => 20,
        'option'  => 'wc_quick_per_page',
    );

        add_screen_option( $options, $args );
    }
}

if (!function_exists('quick_order_settings')) {
    function quick_order_settings()
    {
        quick_get_template_part('quick-order-settings');
    }
}

function quick_order_admin_enqueue_script()
{
    wp_enqueue_style('quick-order-style', QUICK_API.'assets/css/admin.css', array(), QUICK_VERSION );
}

function let_quick_get_default_rows($r)
{
    $rows = get_option( '_quick_no_rows', $r );

    return $rows;
}

function let_quick_get_resultant_products( $rows )
{
    if ( empty( $rows ) ) {
        $rows = 5;
    }

    $args = array(
    'post_type'      => 'product',
    'posts_per_page' => $rows,
    'post_status'    => 'publish',
    'meta_key'       => '_price',
    'meta_value'     => '0',
    'meta_compare'   => '>',
    'meta_query' => array(
          'key'     => '_stock_status',
          'value'   => 'instock',
          'compare' => '=',
    ),
  );

    $loop = new WP_Query($args);

    return $loop;
}

function get_input_search_products()
{
    if (check_ajax_referer('qapi-ajaxnonce', 'nonce', false)) {
        $input = sanitize_text_field($_GET['input']);
        $product_array = array();
        $rows = 10; 

        if (get_option('_search_product_by', 'name') == 'name' || get_option('_search_product_by', 'name') == 'both') {
            $args = array(
            'post_type' => 'product',
            'posts_per_page' => $rows,
            'post_status' => 'publish',
            's' => $input,
        );

            $loop = new WP_Query($args);

            if ($loop->have_posts()) {
                while ($loop->have_posts()) : $loop->the_post();

                global $product;

                $variation = false;

                $product_id = $product->get_id();

                $title = $product->get_formatted_name();

                $type = $product->get_type();

                $is_purchasable = $product->is_purchasable();

                $is_in_stock = $product->is_in_stock();

                $type = $product->get_type();

                if ($type == 'variable') {
                    $variation = true;

                    $is_in_stock = true;

                    $is_purchasable = true;
                }

                $permalink = get_permalink();

                if ($is_in_stock && $is_purchasable) {
                    $product_array[$product_id] = array(
                        'product_id' => $product_id,
                        'title'      => sanitize_text_field( $title ),
                        'variations' => $variation,
                        'permalink'  => $permalink,
                    );
                }

                endwhile;
            }

            if (get_option('_search_product_by', 'name') == 'both') {
                global $wpdb;

                $product_ids = $wpdb->get_col($wpdb->prepare("SELECT post_id FROM $wpdb->postmeta WHERE meta_key='_sku' AND meta_value like'%s' LIMIT 10", '%'.$input.'%'));

                foreach ($product_ids as $key => $product_id) {
                    if ($product_id && !isset($product_array[$product_id])) {
                        $product = wc_get_product($product_id);

                        if ($product) {
                            $variation = false;

                            $product_id = $product->get_id();

                            $title = $product->get_formatted_name();

                            $type = $product->get_type();

                            $is_purchasable = $product->is_purchasable();

                            $is_in_stock = $product->is_in_stock();

                            $type = $product->get_type();

                            if ($type == 'variable') {
                                $variation = true;

                                $is_in_stock = true;

                                $is_purchasable = true;
                            }

                            $permalink = get_permalink();

                            if ($is_in_stock && $is_purchasable) {
                                $product_array[$product_id] = array(
                                                        'product_id' => $product_id,
                                                        'title'      => sanitize_text_field( $title ),
                                                        'variations' => $variation,
                                                        'permalink'  => $permalink,
                                                       );
                            }
                        }
                    }
                }
                if (count($product_array) > 10) {
                    $product_array = array_slice($product_array, 0, 10, true);
                }
            }
        } elseif (get_option('_search_product_by', 'name') == 'sku') {
            global $wpdb;

            $product_ids = $wpdb->get_col($wpdb->prepare("SELECT post_id FROM $wpdb->postmeta WHERE meta_key='_sku' AND meta_value like'%s' LIMIT 10", '%'.$input.'%'));

            foreach ($product_ids as $key => $product_id) {
                if ($product_id) {
                    $product = wc_get_product($product_id);
                    if ($product) {
                        $variation = false;

                        $product_id = $product->get_id();

                        $title = $product->get_formatted_name();

                        $type = $product->get_type();

                        $is_purchasable = $product->is_purchasable();

                        $is_in_stock = $product->is_in_stock();

                        $type = $product->get_type();

                        if ($type == 'variable') {
                            $variation = true;

                            $is_in_stock = true;

                            $is_purchasable = true;
                        }

                        $permalink = get_permalink();

                        if ($is_in_stock && $is_purchasable) {
                            $product_array[$product_id] = array(
                                                        'product_id' => $product_id,
                                                        'title' => sanitize_text_field( $title ),
                                                        'variations' => $variation,
                                                        'permalink' => $permalink,
                                                       );
                        }
                    }
                }
            }
        }

        if (empty($product_array)) {
            $product_array[0] = array(
                'product_id' => 0,
                'title'      => esc_attr__('No Product Found!', 'wk_quick'),
                'variations' => array(),
            );
        }

        wp_send_json($product_array);

        wp_die();
    }
}// end of get_input_seach_products

function bulk_add_multiple_products_via_csv_to_cart()
{
    if ($_FILES['wk_quick_order_file']['name'] && $_FILES['wk_quick_order_file']['name']) {
        $uploadOk = 1;

        try {
            $csv_tmpName = $_FILES['wk_quick_order_file']['tmp_name'];

            $csv_name = $_FILES['wk_quick_order_file']['name'];
            if (!function_exists('mime_content_type')) {
                throw new Exception();
            } else {
                $csv_type = mime_content_type($_FILES['wk_quick_order_file']['tmp_name']);

                $csv_size = $_FILES['wk_quick_order_file']['size'];

                // Check file size
                if ($csv_size > 5000000) {
                    echo "<div class='csv-error'>" . esc_html__( 'Sorry, your csv file is too large.', 'wk_quick' ) . "</div>";
                    $uploadOk = 0;
                }

                $allowed_csv_type = array('text/csv', 'application/csv', 'text/plain');

                // Allow certain file formats
                if (!in_array($csv_type, $allowed_csv_type)) {
                    echo "<div class='csv-error'>" . esc_html__( 'Sorry, only CSV files are allowed.', 'wk_quick' ) . "</div>";
                    $uploadOk = 0;
                }

                // Check if $uploadOk is set to 0 by an error
                if ($uploadOk == 0) {
                    echo "<div class='csv-error'>" . esc_html__( 'Sorry, something wrong with file.', 'wk_quick' ) . "</div>";
                } else {
                    // if everything is ok, try to upload file
                    $data = array_map('str_getcsv', file($csv_tmpName));

                    if (!empty($data)) {
                        foreach ($data as $id => $quantity) {
                            if (!empty($quantity) && isset($quantity[0]) && isset($quantity[1]) && !empty($quantity[1])) {
                                $product_id = is_sku_exist($quantity[0]);
                                // If draft product exists inside file, indicate to user that it is not allowed.
                                if ($product_id) {
                                    if ('publish' === get_post_status($product_id)) {
                                        WC()->cart->add_to_cart($product_id, $quantity[1]);
                                    }
                                    // ISSUE 23
                                    if('draft' === get_post_status($product_id)) {
                                       
                                        wc_add_notice( esc_html__( 'You have tried to add a Draft Product, [SKU/ID]: '. $quantity[0] . ' .Not allowed.', 'wk_quick' ), 'error' );
                                    }
                                } else {
                                    if ('publish' === get_post_status( $quantity[0 ]) ) {
                                        WC()->cart->add_to_cart($quantity[0], $quantity[1]);
                                    }
                                    // ISSUE 23
                                    if( 'draft' === get_post_status( $quantity[0] ) ) {
                                        
                                        wc_add_notice( esc_html__( 'You have tried to add a Draft Product, [SKU/ID]: '. $quantity[0] . ' .Not allowed.', 'wk_quick' ), 'error' );
                                    }
                                }
                            }
                        }

                        $lw_redirect_checkout = wc_get_cart_url();
                        wp_redirect($lw_redirect_checkout);
                        exit;
                    }
                }
            }
        } catch (Exception $ex) {
            wc_add_notice(esc_html__('To upload the file, enable fileinfo.so or php_fileinfo.dll in the php.ini file', 'wk_quick'), 'error');
        }
    } else {
        echo '<div class="csv-error">' . esc_html__( 'Please select files.', 'wk_quick' ) . '</div>';
    }
}

function is_sku_exist($sku)
{
    global $wpdb;

    $product_id = $wpdb->get_var($wpdb->prepare("SELECT post_id FROM $wpdb->postmeta WHERE meta_key='_sku' AND meta_value='%s' LIMIT 1", $sku));

    return $product_id;
}

function bulk_add_multiple_products_to_cart()
{
    if (isset($_POST['qty']) && isset($_POST['ref'])) {
        $quantity = $_POST['qty'];
        $ref_id = $_POST['ref'];
        $variation = $_POST['idProductAttribute'];

        if (!empty($quantity) && !empty($ref_id) && count($ref_id) == count($quantity)) {
            foreach ($ref_id as $rkey => $rvalue) {
                if ($variation[$rkey] != '-1') {
                    WC()->cart->add_to_cart($rvalue, $quantity[$rkey], $variation[$rkey]);
                } else {
                    WC()->cart->add_to_cart($rvalue, $quantity[$rkey]);
                }
            }

            $lw_redirect_cart = wc_get_cart_url();
            wp_redirect($lw_redirect_cart);
            exit();
        }
    }
}

function get_add_product_tmpl()
{
    if (check_ajax_referer('qapi-ajaxnonce', 'nonce', false)) {
        $no_rows = get_option( '_quick_no_rows_add', 5 );

        $rows = !empty($no_rows) ? $no_rows : 5;

        ob_start();

        if (!empty($rows)) :

        while ($rows) :

          quick_get_template_part('tmpl/product-tmpl');

        --$rows;

        endwhile;

        endif;

        $content = ob_get_clean();

        wp_send_json($content);

        wp_die();
    }
}



function get_input_selected_product()
{
    if (check_ajax_referer('qapi-ajaxnonce', 'nonce', false)) {
        $input = intval($_GET['input']);

        $rows = 10;

        $args = array(
        'post_type' => 'product',
        'posts_per_page' => $rows,
        'post_status' => 'publish',
        'post__in' => array($input),
      );

        $loop = new WP_Query($args);

        $product_array = array();

        if ($loop->have_posts()) :

        while ($loop->have_posts()) : $loop->the_post();

        // code...

        global $product;

        $stock_status = $product->get_stock_status();

        if ($stock_status) {
            $variation = false;

            $product_id = $product->get_id();

            $title = $product->get_title();

            $price = $product->get_price_html();

            $image = woocommerce_get_product_thumbnail();

            $stock = $product->get_stock_quantity();

            $type = $product->get_type();

            $sku = $product->get_sku();

            if ($type == '') {
            }

            if ($type == 'variable') {
                $variation = array();

                $product_variations = $product->get_available_variations();

                foreach ($product_variations as $key => $value) {
                    $variation_title = array();

                    $is_active = $value['variation_is_active'];

                    $is_in_stock = $value['is_in_stock'];

                    $is_purchasable = $value['is_purchasable'];

                    if ($is_active && $is_purchasable && $is_in_stock) {
                        $variation_id = $value['variation_id'];

                        $variation_image = $value['image']['src'];

                        $variation_price = $value['display_price'];

                        $variation_min_qty = $value['min_qty'];

                        $variation_max_qty = $value['max_qty'];

                        foreach ($value['attributes'] as $vkey => $vvalue) {
                            if (strpos($vkey, 'attribute_pa_') !== false) {
                                $vkey = str_replace('attribute_pa_', '', $vkey);
                            } else {
                                $vkey = str_replace('attribute_', '', $vkey);
                            }

                            array_push($variation_title, array($vkey => $vvalue));
                        }

                        array_push($variation,
                    array(
                      'variation_id' => $variation_id,
                      'variation_formated_price' => wc_price($variation_price),
                      'variation_price' => $variation_price,
                      'variation_image' => $variation_image,
                      'variation_attributes' => $variation_title,
                      'variation_min_stock' => $variation_min_qty,
                      'variation_max_stock' => $variation_max_qty,
                      'variation_sku' => !empty($value['sku']) ? $value['sku'] : '',
                    )
                  );
                    }
                }
            }

            $permalink = get_permalink();

            $product_array = array(
              'product_id' => $product_id,
              'title'      => sanitize_text_field( $title ),
              'price'      => $price,
              'image'      => $image,
              'stock'      => $stock,
              'variations' => $variation,
              'sku'        => $sku,
              'permalink'  => $permalink,
            );
        }

        endwhile;

        endif;

        wp_send_json($product_array);

        wp_die();
    }
}

function quick_order_front_enqueue_script()
{
    $qovariable_arr = array();

    wp_enqueue_script('quick-order-script', QUICK_API.'assets/js/quick-order.js', array('jquery'), '1.0');

    wp_localize_script('quick-order-script', 'qapif_script', array('qapi_admin_ajax' => admin_url('admin-ajax.php'), 'quick_api_nonce' => wp_create_nonce('qapi-ajaxnonce'), 'quick-order_tr' => $qovariable_arr));
}