<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

    $blank_row = get_option( '_quick_blank_rows', 1 );

    $product_id = $thumbnail = $permalink = $title = $product_stock = '';
    $product_price = $thumbnail = '--';
    $variation_id = '';

    if ( ! empty( (int) $blank_row) && !empty( $product ) ) {
        
        $type = $product->get_type();

        if ( 'variable' === $type ) {
            $variation = array();

            $product_variations = $product->get_available_variations();

            foreach ($product_variations as $key => $value) {
                if ($key == 0) {
                    $variation_id = $value['variation_id'];

                    break;
                }
            }
        }

        $product_id    = $product->get_id();
        $permalink     = get_permalink();
        $thumbnail     = woocommerce_get_product_thumbnail();
        $title         = get_the_title();
        $product_price = $product->get_price_html();
        $product_stock = $product->get_stock_quantity();

        // ISSUE 19 - Qty set to 1 automatically (if below conditions apply). 
        if($product_stock == null || $product_stock == 0)
        {
            $product_stock = 1; 
        }
           
        $product_sku = $product->get_sku();
    }

    if ( get_option( '_search_product_by', 'name' ) == 'name' ) {
        $place_holder = esc_attr__( 'Enter Product Name', 'wk_quick' );
    } elseif ( get_option( '_search_product_by', 'name') == 'sku') {
        $place_holder = esc_attr__( 'Enter Product SKU', 'wk_quick' );
    } elseif ( get_option( '_search_product_by', 'name') == 'both') {
        $place_holder = esc_attr__( 'Enter Product Name/SKU', 'wk_quick' );
    }

?>


<tr class="woocommerce-orders-table__row">
<?php if (apply_filters('wkwc_quick_order_remove_sku_field_from_from', true)) {
    ?>
    <td data-title="<?php echo esc_attr__('SKU', 'wk_quick'); ?>" class="woocommerce-orders-table__cell wk_qo_product_sku_col" >
        <input class="form-control wk_qo_product_sku" name="sku[]" type="text" value="<?php echo !empty($product_sku) ? $product_sku : ''; ?>" placeholder="Sku" autocomplete="off">
        <div class="wk_quick_order_products_ul wk_qo_product_list_div"></div>

        <!-- ISSUE 14 -->
        <div class="wk_qo_products_search_list wk_qo_product_list_div"></div>
    </td>
    <?php
} ?>
    <td class="wk_qo_product_ref_col" style="display:none;">
        <input class="form-control wk_qo_product_ref" name="ref[]" type="hidden" value="<?php echo !empty($variation_id) ? $variation_id : $product_id; ?>" placeholder="Reference" autocomplete="off">
        <div class="wk_quick_order_products_ul wk_qo_product_list_div"></div>
    </td>
    <td data-title="<?php echo esc_attr__('Image', 'wk_quick'); ?>" class="woocommerce-orders-table__cell wk_qo_product_img_col">
        <span class="product-image media-middle">
        <!-- ISSUE 15 target blank image -->
            <a href="<?php echo esc_url( $permalink ); ?>" target="_blank" title="<?php echo esc_attr( $title ); ?>" rel="noopener">
                <?php echo wp_kses_post( $thumbnail ); ?>
            </a>
        </span>
    </td>
   
    <td data-title="<?php echo esc_attr__('Name', 'wk_quick'); ?>" class="woocommerce-orders-table__cell wk_qo_product_name_col">
        <input class="form-control wk_qo_product_name" name="idProduct[]" type="text" value="<?php echo $title; ?>" placeholder="<?php echo $place_holder; ?>" autocomplete="off">
        <div class="wk_qo_product_info wk_quick_order_error"></div>
        <div class="wk_qo_products_search_list wk_qo_product_list_div"></div>
    </td>
   <?php
     if ( get_option( '_create_combination_feild', 'yes' ) == 'yes' ) {
         if ( ! empty( $product ) ) {
             switch ( $product->get_type() ) {
                 case 'simple':
                    quick_get_template_part('tmpl/simple/simple-product-tmpl');
                    break;
                 case 'variable':
                    quick_get_template_part('tmpl/variable/variable-product-tmpl');
                    break;
                 default:
                    quick_get_template_part('tmpl/simple/simple-product-tmpl');
                    break;
            }
        } else {
            quick_get_template_part('tmpl/simple/simple-product-tmpl');
        }
     }

 ?>
 
    <td data-title="<?php echo esc_attr__('Quantity', 'wk_quick'); ?>" class="woocommerce-orders-table__cell wk_qo_product_quantity">
        <div class="qty">
            <div class="input-group "><input type="number" name="qty[]" min="1" max="<?php echo $product_stock; ?>" value="1" class="input-group wk-quick-order-qty form-control" data-price="" aria-label="Quantity" ></div>
        </div>
    </td>
    <td data-title="<?php echo esc_attr__( 'Price', 'wk_quick' ); ?>" class="woocommerce-orders-table__cell wk_qo_product_price">
        <span><?php echo $product_price; ?></span>
    </td>
    <td data-title="<?php echo esc_attr__( 'Action', 'wk_quick' ); ?>" class="woocommerce-orders-table__cell wk_quick_order_delete_row">
        <i class="wk_quick_order_delete_icon"></i>
    </td>
</tr>