<?php
/**
 * Plugin Name: WooCommerce Quick Order
 * Plugin URI: https://store.webkul.com/woocommerce-point-of-sale.html
 * Description: Woocommerce Quick Order module will provid the functionality to customer that they can add multiple product to cart
 * Version: 1.1.3
 * Author: Webkul
 * Author URI: http://webkul.com
 * License: GNU/GPL for more info see license.txt included with plugin
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: wk_quick
 * WC requires at least: 3.0.0
 * WC tested up to: 3.9.1.
 * Wordpress Tested up to: 5.3.2
 **/

/*---------------------------------------------------------------------------------------------*/

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

if ( ! class_exists( 'Woo_Quick_Order' ) ) {

    final class Woo_Quick_Order
    {
        private static $_instance = null;

        public static function instance()
        {
            if (is_null(self::$_instance)) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }

        private function includes()
        {
            // Include required files.

            require_once 'includes/class-quick-defaults.php';

            require_once 'includes/class-quickhooks.php';

            require_once 'includes/class-quick-order-functions.php';

            require_once 'includes/class-quick-template-loader.php';

            require_once 'includes/class-quick-order-form-handler.php';

            
        }

        public function __construct()
        {
            ob_start();

            // Auto-load classes on demand.
            if (function_exists('__autoload')) {
                spl_autoload_register('__autoload');
            }

            $this->quick_define_constants();

            $this->includes();
        }

        public function quick_define_constants()
        {
            define( 'WC_QUICK_PLUGIN_FILE', __FILE__ );

            define( 'QUICK_DIR', untrailingslashit( plugin_dir_path( __FILE__ ) ) );

            define( 'QUICK_VERSION', '1.1.3') ;

            define( 'QUICK_API', plugin_dir_url( __FILE__ ) );
        }

    }

    add_action( 'plugins_loaded',  function() {
        if ( ! function_exists( 'WC' ) ) {
            // Add WooCommerce dependency Message
            add_action(
                'admin_notices', function () { ?>
                    <div class="error">
                        <p><?php echo sprintf( esc_html__( 'Woocommerce Quick Order depends on the last version of %s or later to work!', 'wk_quick' ), '<a href="http://www.woothemes.com/woocommerce/" target="_blank">' . esc_html__( 'WooCommerce', 'wk_quick' ) . '</a>' ) ?></p>
                    </div>
                <?php } 
            );
        } else {
            // Load Text domain
            ob_start();
            load_plugin_textdomain( 'wk_quick', false, basename( dirname( __FILE__ ) ) . '/languages' );
            new Woo_Quick_Order();
        }
    });
} else {
    add_action(
        'admin_notices', function () { ?>
            <div class="error">
                <p><?php esc_html_e( 'Woocommerce Quick Order unable not work due to class name conflict', 'wk_quick' ); ?></p>
            </div>
        <?php } 
    );
}

require_once 'includes/class-quick-install.php';

register_activation_hook( __FILE__, array( new Wc_Quick_Install(), 'wc_quick_install' ) );